@@ -629,7 +629,7 @@ class MoviePatchData:
             return False
         if self.cell != other.cell:
             return False
-        if self.index_movie != self.index_movie:
+        if self.index_movie != other.index_movie:
             return False
         return True
 
