@@ -868,7 +868,7 @@ class CinacFileWriter:
         return None
 
 
-def read_cell_type_categories_yaml_file(yaml_file, using_multi_class):
+def read_cell_type_categories_yaml_file(yaml_file, using_multi_class=2):
     """
     Read cell type categories from a yaml file. If more than 2 type cells are given, then a multi-class
     classifier will be used. If 2 type cells are given, then either it could be multi-class or binary classifier,
@@ -877,7 +877,8 @@ def read_cell_type_categories_yaml_file(yaml_file, using_multi_class):
     if we get more than 0.5 probability.
     Args:
         yaml_file:
-        using_multi_class: int, give the default parameters used
+        using_multi_class: int, give the default number of classes used, not necessary if already
+        put in the yaml file
 
     Returns: cell_type_from_code_dict, cell_type_to_code_dict, multi_class_arg
     cell_type_from_code_dict: dict, key is an int, value is the cell_type
@@ -908,26 +909,53 @@ def read_cell_type_categories_yaml_file(yaml_file, using_multi_class):
             n_cell_categories = len(args_content)
             # if multi_class == 1, then we need a predicted_cell_type which will have the value 1
             predicted_cell_type = None
+            print(f"args_content {args_content}")
+            # args_content is a list of dict, key is the cell_type name, value is a dict
+            # with keywords (list of string as value) and predicted_celll_type (bool as value)
             if (multi_class_arg is None and using_multi_class == 1) or (multi_class_arg is False):
-                for cell_type_category, category_dict in args_content.items():
-                    if "predicted_cell_type" in category_dict:
-                        predicted_cell_type = cell_type_category
-            for cell_type_category, category_dict in args_content.items():
-                if (predicted_cell_type is not None) and (predicted_cell_type == cell_type_category) and \
-                        (n_cell_categories <= 2):
-                    cell_type_from_code_dict[1] = cell_type_category
-                    cell_type_code = 1
-                else:
-                    cell_type_from_code_dict[category_code_increment] = cell_type_category
-                    cell_type_code = category_code_increment
-                    category_code_increment += 1
-                    if (category_code_increment == 1) and (predicted_cell_type is not None) and \
+                # for cell_type_category, category_dict in args_content.items():
+                #     if "predicted_celll_type" in category_dict:
+                #         predicted_cell_type = cell_type_category
+                for cell_type_dict in args_content:
+                    for cell_type_category, category_dict in cell_type_dict.items():
+                        if "predicted_celll_type" in category_dict:
+                            predicted_cell_type = cell_type_category
+
+            # for cell_type_category, category_dict in args_content.items():
+            #     if (predicted_cell_type is not None) and (predicted_cell_type == cell_type_category) and \
+            #             (n_cell_categories <= 2):
+            #         cell_type_from_code_dict[1] = cell_type_category
+            #         cell_type_code = 1
+            #     else:
+            #         cell_type_from_code_dict[category_code_increment] = cell_type_category
+            #         cell_type_code = category_code_increment
+            #         print(f"cell_type_category {cell_type_category}: {cell_type_code}")
+            #         category_code_increment += 1
+            #         if (category_code_increment == 1) and (predicted_cell_type is not None) and \
+            #                 (n_cell_categories <= 2):
+            #             category_code_increment += 1
+            #     cell_type_to_code_dict[cell_type_category] = cell_type_code
+            #     if "keywords" in category_dict:
+            #         for keyword in category_dict["keywords"]:
+            #             cell_type_to_code_dict[keyword] = cell_type_code
+            for cell_type_dict in args_content:
+                for cell_type_category, category_dict in cell_type_dict.items():
+                    if (predicted_cell_type is not None) and (predicted_cell_type == cell_type_category) and \
                             (n_cell_categories <= 2):
+                        cell_type_from_code_dict[1] = cell_type_category
+                        cell_type_code = 1
+                    else:
+                        cell_type_from_code_dict[category_code_increment] = cell_type_category
+                        cell_type_code = category_code_increment
+                        print(f"cell_type_category {cell_type_category}: {cell_type_code}")
                         category_code_increment += 1
-                cell_type_to_code_dict[cell_type_category] = cell_type_code
-                if "keywords" in category_dict:
-                    for keyword in category_dict["keywords"]:
-                        cell_type_to_code_dict[keyword] = cell_type_code
+                        if (category_code_increment == 1) and (predicted_cell_type is not None) and \
+                                (n_cell_categories <= 2):
+                            category_code_increment += 1
+                    cell_type_to_code_dict[cell_type_category] = cell_type_code
+                    if "keywords" in category_dict:
+                        for keyword in category_dict["keywords"]:
+                            cell_type_to_code_dict[keyword] = cell_type_code
 
     return cell_type_from_code_dict, cell_type_to_code_dict, multi_class_arg
 
